@@ -27,7 +27,6 @@ from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import GObject
-import uaclient.api.u.pro.packages.updates.v1 as ua
 
 GdkX11  # pyflakes
 
@@ -41,7 +40,6 @@ import os
 import subprocess
 import sys
 import time
-import threading
 from gettext import gettext as _
 
 import dbus
@@ -55,7 +53,6 @@ from .Dialogs import (DistUpgradeDialog,
                       HWEUpgradeDialog,
                       NeedRestartDialog,
                       NoUpdatesDialog,
-                      NoUpgradeForYouDialog,
                       PartialUpgradeDialog,
                       StoppedUpdatesDialog,
                       UnsupportedDialog,
@@ -66,7 +63,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
+from .Core.utils import get_dist
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -87,11 +84,9 @@ class UpdateManager(Gtk.Window):
         self.unity = UnitySupport()
         self.controller = None
         self.cache = None
-        self.ua_security_packages = []
         self.update_list = None
         self.meta_release = None
         self.hwe_replacement_packages = None
-        self.arch = get_arch()
 
         # Basic GTK+ parameters
         self.set_title(_("Software Updater"))
@@ -196,13 +191,9 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
-        try:
-            apt_pkg.pkgsystem_unlock()
-        except SystemError:
-            pass
+    def show_settings(self):
         cmd = ["/usr/bin/software-properties-gtk",
-               "--open-tab", str(page_number)]
+               "--open-tab", "2"]
 
         if "WAYLAND_DISPLAY" not in os.environ:
             cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
@@ -242,68 +233,15 @@ class UpdateManager(Gtk.Window):
         self._look_busy()
         self.refresh_cache()
 
-        if self.cache is None:
-            return
-
         pane = self._make_available_pane(self.cache.install_count,
                                          os.path.exists(REBOOT_REQUIRED_FILE),
                                          cancelled_update, error_occurred)
         self._start_pane(pane)
 
-    def _fetch_ua_updates(self):
-        try:
-            self.ua_updates = ua.updates().updates
-        except Exception as e:
-            print("Error running updates end-point: ", e)
-            self.ua_updates = []
-
-    def _get_ua_security_status(self):
-        self.ua_security_packages = []
-        self.ua_updates = []
-        t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
-        t.start()
-        while t.is_alive():
-            while Gtk.events_pending():
-                Gtk.main_iteration()
-            time.sleep(0.05)
-        for package in self.ua_updates:
-            if (
-                package.provided_by == 'standard-security'
-                or package.provided_by == 'standard-updates'
-            ):
-                continue
-            status = package.status
-            if (
-                status == 'pending_attach'
-                or status == 'pending_enable'
-                or status == 'upgrade_available'
-            ):
-                name = package.package
-                version = package.version
-                size = package.download_size
-                downloadable = status == 'upgrade_available'
-                self.ua_security_packages.append(
-                    (name, version, size, downloadable)
-                )
-        self.cache.create_pro_cache(self.ua_security_packages)
-
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
         self._check_hwe_support_status()
-        if install_count != 0:
-            header = None
-            desc = None
-            if error_occurred:
-                desc = _("Some software couldn’t be checked for updates.")
-            elif cancelled_update:
-                header = _("You stopped the check for updates.")
-                desc = _("Updated software is available from "
-                         "a previous check.")
-            # Display HWE updates first as an old HWE stack is vulnerable
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
-            return UpdatesAvailable(self, header, desc, need_reboot)
-        else:
+        if install_count == 0:
             # Need Restart > New Release > No Updates
             if need_reboot:
                 return NeedRestartDialog(self)
@@ -316,6 +254,19 @@ class UpdateManager(Gtk.Window):
                 return HWEUpgradeDialog(self)
             else:
                 return NoUpdatesDialog(self, error_occurred=error_occurred)
+        else:
+            header = None
+            desc = None
+            if error_occurred:
+                desc = _("Some software couldn’t be checked for updates.")
+            elif cancelled_update:
+                header = _("You stopped the check for updates.")
+                desc = _("Updated software is available from "
+                         "a previous check.")
+            # Display HWE updates first as an old HWE stack is vulnerable
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            return UpdatesAvailable(self, header, desc, need_reboot)
 
     def start_error(self, update_and_retry, header, desc):
         if update_and_retry:
@@ -354,12 +305,9 @@ class UpdateManager(Gtk.Window):
 
         # Check for new fresh release
         settings = Gio.Settings.new("com.ubuntu.update-manager")
-        if (self.meta_release.new_dist and
-                (self.options.check_dist_upgrades or
-                 settings.get_boolean("check-dist-upgrades"))):
-            if self.arch == 'i386':
-                return NoUpgradeForYouDialog(self, self.meta_release,
-                                             self.arch)
+        if (self.meta_release.new_dist
+                and (self.options.check_dist_upgrades
+                     or settings.get_boolean("check-dist-upgrades"))):
             return DistUpgradeDialog(self, self.meta_release)
 
         return None
@@ -405,12 +353,6 @@ class UpdateManager(Gtk.Window):
 
     # fixme: we should probably abstract away all the stuff from libapt
     def refresh_cache(self):
-        # get the lock
-        try:
-            apt_pkg.pkgsystem_lock()
-        except SystemError:
-            pass
-
         try:
             if self.cache is None:
                 self.cache = MyCache(None)
@@ -428,8 +370,7 @@ class UpdateManager(Gtk.Window):
                      "Please use the package manager \"Synaptic\" or run "
                      "\"sudo apt-get install -f\" in a terminal to fix "
                      "this issue at first.")
-            self.start_error(False, header, desc)
-            return
+            self.start_error(True, header, desc)
         except SystemError as e:
             header = _("Could not initialize the package information")
             desc = _("An unresolvable problem occurred while "
@@ -437,8 +378,7 @@ class UpdateManager(Gtk.Window):
                      "Please report this bug against the 'update-manager' "
                      "package and include the following error "
                      "message:\n") + str(e)
-            self.start_error(False, header, desc)
-            return
+            self.start_error(True, header, desc)
 
         # Let the Gtk event loop breath if it hasn't had a chance.
         def iterate():
@@ -446,13 +386,9 @@ class UpdateManager(Gtk.Window):
                 Gtk.main_iteration()
         iterate()
 
-        self._get_ua_security_status()
-
         self.update_list = UpdateList(self)
         try:
-            self.update_list.update(self.cache, eventloop_callback=iterate,
-                                    ua_security_packages=self.
-                                    ua_security_packages)
+            self.update_list.update(self.cache, eventloop_callback=iterate)
         except SystemError as e:
             header = _("Could not calculate the upgrade")
             desc = _("An unresolvable problem occurred while "
